Contributors
============

Main contributors:

- `Alessandro Amici <https://github.com/alexamici>`_ - `B-Open <https://bopen.eu>`_
- `Sandor Kertesz <https://github.com/sandorkertesz>`_ - `ECMWF <https://ecmwf.int>`_
- `Iain Russell <https://github.com/iainrussell>`_ -  `ECMWF <https://ecmwf.int>`_

Also:
- Daniel Lee - DWD, who contributed the code in the high_level_bufr directory, originally part of eccodes-python

See also the list of `contributors <https://github.com/ecmwf/pdbufr/contributors>`_ who participated in this project.
